@@ -18,7 +18,8 @@
 #           (doppler and range swap in V6 output)
 # v0.1.2 : 2021/09/17
 #           v7 dataframe:'tid' move to front of 'ec0'
-#
+# v1.0.0 : 2022/07/18
+#           add tilt and install and sx,sy,sz in raw data mode
 
 import serial
 import time
@@ -50,6 +51,7 @@ class Pc3OVH:
 	
 	magicWord =  [b'\x02',b'\x01',b'\x04',b'\x03',b'\x06',b'\x05',b'\x08',b'\x07',b'\0x99']
 	port = ""
+	height = 0.0
 	hdr = header
 	u = unitS
 	
@@ -76,14 +78,17 @@ class Pc3OVH:
 	sm  = False #Observed StateMachine: True Show message
 	plen = 16 
 	
-	def __init__(self,port):
+	def __init__(self,port, tiltAngle = None, height = None):
 		self.port = port
+		self.height = 0.0 if height == None else height
+		self.elv_tilt = 0.0 if tiltAngle == None else tiltAngle * np.pi/180.0 
 		print("(jb)OverHead People Counting 3D initial")
-		print("(jb)vsersion:v0.1.0")
+		print("(jb)version:v1.0.0")
 		print("(jb)For Hardware:Batman-201(ISK) & BM-501 (AOP)")
 		print("(jb)Hardware: IWR-6843 & AOP")
 		print("(jb)Firmware: PC3-I471")
 		print("(jb)UART Baud Rate:921600")
+		print(f"(jb)Radar tilt degree:{tiltAngle}°")
 		print("Output: V6,V7,V8 data:(RAW)")
 		
 	def useDebug(self,ft):
@@ -199,6 +204,8 @@ class Pc3OVH:
 		v6df = ([])
 		v7df = ([])
 		v8df = ([])
+		 
+		
 		
 		while True:
 			try:
@@ -339,22 +346,32 @@ class Pc3OVH:
 					try:
 						#print(":".join("{:02x}".format(c) for c in sbuf))
 						(e,a,d,r,s) = struct.unpack('2b3h', sbuf)
+						
 						elv = e * self.u.elevationUnit
 						azi = a * self.u.azimuthUnit
 						dop = d * self.u.dopplerUnit
 						ran = r * self.u.rangeUnit
 						snr = s * self.u.snrUnit
-						#print("({:2d}:{:4d})(idx:({:4d}) elv:{:.4f} azimuth:{:.4f} doppler:{:.4f} range:{:.4f} snr:{:.4f}".format(numOfPoints,lenCount,idx,elv,azi,dop,ran,snr))
+						
+						sz0  = ran * np.sin(elv)
+						sx  = ran * np.cos(elv) * np.sin(azi)
+						sy0  = ran * np.cos(elv) * np.cos(azi)
+						sz = sz0
+						sy = sy0
+						
+						# tilt 
+						if self.elv_tilt != 0.0:
+							sy =sy0 * np.cos(self.elv_tilt) - sz0 * np.sin(self.elv_tilt) 
+							sz =sy0 * np.sin(self.elv_tilt) + sz0 * np.cos(self.elv_tilt)
+						
+						sy = self.height - sy
+						
 						
 						if (df == 'DataFrame'):
-							sz  = ran * np.sin(elv)
-							sx  = ran * np.cos(elv) * np.sin(azi)
-							sy  = ran * np.cos(elv) * np.cos(azi)
 							#v6df.append((self.hdr.frameNumber,'v6',elv,azi,dop,ran,snr,sx,sy,sz)) #v0.1.0
-							v6df.append((self.hdr.frameNumber,'v6',elv,azi,ran,dop,snr,sx,sy,sz)) #v0.1.1
-							 
+							v6df.append((self.hdr.frameNumber,'v6',elv,azi,ran,dop,snr,sx,sy,sz)) #v0.1.1 
 						else:
-							v6.append((elv,azi,dop,ran,snr))
+							v6.append((elv,azi,dop,ran,snr,sx,sy,sz))
 						
 						#print("point_cloud_2d.append:[{:d}]".format(len(point_cloud_2d)))
 						sbuf = b""
